@@ -1,5 +1,5 @@
 #
-# Copyright 2018-2020 IBM Corporation
+# Copyright 2018-2021 Elyra Authors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 #
 import autopep8
 import kfp
+import kfp_tekton
 import os
 import tempfile
 import time
@@ -68,13 +69,17 @@ class KfpPipelineProcessor(PipelineProcessor):
 
             self.log.debug("Creating temp directory %s", temp_dir)
 
+            engine = runtime_configuration.metadata.get('engine')
             # Compile the new pipeline
             try:
                 pipeline_function = lambda: self._cc_pipeline(pipeline, pipeline_name)  # nopep8 E731
-                kfp.compiler.Compiler().compile(pipeline_function, pipeline_path)
+                if 'Tekton' == engine:
+                    kfp_tekton.compiler.TektonCompiler().compile(pipeline_function, pipeline_path)
+                else:
+                    kfp.compiler.Compiler().compile(pipeline_function, pipeline_path)
             except Exception as ex:
-                raise RuntimeError('Error compiling pipeline {} at {}'.
-                                   format(pipeline_name, pipeline_path), str(ex)) from ex
+                raise RuntimeError('Error compiling pipeline {} for engine {} at {}'.
+                                   format(pipeline_name, engine, pipeline_path), str(ex)) from ex
 
             self.log.debug("Kubeflow Pipeline was created in %s", pipeline_path)
 
@@ -88,7 +93,7 @@ class KfpPipelineProcessor(PipelineProcessor):
                                                                     api_username,
                                                                     api_password)
 
-            client = kfp.Client(host=api_endpoint, cookies=session_cookie)
+            client = kfp_tekton.TektonClient(host=api_endpoint, cookies=session_cookie)
 
             try:
                 description = f"Created with Elyra {__version__} pipeline editor using '{pipeline.name}.pipeline'."
@@ -139,6 +144,7 @@ class KfpPipelineProcessor(PipelineProcessor):
 
         runtime_configuration = self._get_runtime_configuration(pipeline.runtime_config)
         api_endpoint = runtime_configuration.metadata['api_endpoint']
+        engine = runtime_configuration.metadata.get('engine')
 
         if os.path.exists(absolute_pipeline_export_path) and not overwrite:
             raise ValueError("File " + absolute_pipeline_export_path + " already exists.")
@@ -147,7 +153,13 @@ class KfpPipelineProcessor(PipelineProcessor):
         if pipeline_export_format != "py":
             try:
                 pipeline_function = lambda: self._cc_pipeline(pipeline, pipeline_name)  # nopep8
-                kfp.compiler.Compiler().compile(pipeline_function, absolute_pipeline_export_path)
+
+                if 'Tekton' == engine:
+                    self.log.info("Compiling pipeline for Tekton engine")
+                    kfp_tekton.compiler.TektonCompiler().compile(pipeline_function, absolute_pipeline_export_path)
+                else:
+                    self.log.info("Compiling pipeline for Argo engine")
+                    kfp.compiler.Compiler().compile(pipeline_function, absolute_pipeline_export_path)
             except Exception as ex:
                 raise RuntimeError('Error compiling pipeline {} for export at {}'.
                                    format(pipeline_name, absolute_pipeline_export_path), str(ex)) from ex
@@ -155,7 +167,7 @@ class KfpPipelineProcessor(PipelineProcessor):
             # Load template from installed elyra package
             t0 = time.time()
             loader = PackageLoader('elyra', 'templates')
-            template_env = Environment(loader=loader)
+            template_env = Environment(loader=loader, trim_blocks=True)
 
             template_env.filters['to_basename'] = lambda path: os.path.basename(path)
 
@@ -176,6 +188,7 @@ class KfpPipelineProcessor(PipelineProcessor):
 
             python_output = template.render(operations_list=defined_pipeline,
                                             pipeline_name=pipeline_name,
+                                            engine=engine,
                                             api_endpoint=api_endpoint,
                                             pipeline_description=description,
                                             writable_container_dir=self.WCD)
@@ -270,6 +283,9 @@ class KfpPipelineProcessor(PipelineProcessor):
                                                     pipeline_outputs=operation.outputs,
                                                     pipeline_envs=pipeline_envs,
                                                     emptydir_volume_size=emptydir_volume_size,
+                                                    cpu_request=operation.cpu,
+                                                    mem_request=operation.memory,
+                                                    gpu_limit=operation.gpu,
                                                     image=operation.runtime_image,
                                                     file_outputs={
                                                         'mlpipeline-metrics':
