@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2020 IBM Corporation
+ * Copyright 2018-2021 Elyra Authors
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@
  */
 describe('SubmitButton', () => {
   it('opens jupyterlab', () => {
-    cy.visit('?token=test&reset');
+    cy.openJupyterLab();
   });
 
   it('opens blank notebook', () => {
